This is unreleased documentation for the main (development) branch of crypto-glue.

ExtendableOutputCore

Trait ExtendableOutputCore 

pub trait ExtendableOutputCore: UpdateCore + BufferKindUser {
    type ReaderCore: XofReaderCore;

    // Required method
    fn finalize_xof_core(
        &mut self,
        buffer: &mut Buffer<Self>,
    ) -> Self::ReaderCore;
}
Core trait for hash functions with extendable (XOF) output size.

Required Associated Types

type ReaderCore: XofReaderCore

XOF reader core state.

Required Methods

fn finalize_xof_core(&mut self, buffer: &mut Buffer<Self>) -> Self::ReaderCore

Retrieve XOF reader using remaining data stored in the block buffer and leave hasher in a dirty state.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors