pub trait VariableOutputCoreCustomized: VariableOutputCore {
// Required method
fn new_customized(customization: &[u8], output_size: usize) -> Self;
}Expand description
Trait adding customization string to hash functions with variable output.
Required Methods
Sourcefn new_customized(customization: &[u8], output_size: usize) -> Self
fn new_customized(customization: &[u8], output_size: usize) -> Self
Create new hasher instance with the given customization string and output size.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.